@@ -24,10 +24,11 @@ __PACKAGE__->add_columns(
 );
 __PACKAGE__->set_primary_key('id');   
 
-__PACKAGE__->might_have(
+__PACKAGE__->belongs_to(
     'c' => 'DATest::Schema::Test2C', 
     { 'foreign.id'  => 'self.c' },
     { 
+        join_type       => 'left',
         delete_action   => 'delete',
     }
 );
