@@ -69,8 +69,22 @@ CREATE TABLE test5_a (
 CREATE TABLE test5_b (
     id INTEGER PRIMARY KEY AUTOINCREMENT,
     name TEXT NOT NULL,
-    a1 integer,
-    a2 integer
+    a1 INTEGER,
+    a2 INTEGER
+);
+
+DROP TABLE IF EXISTS test6_a;
+DROP TABLE IF EXISTS test6_b;
+
+CREATE TABLE test6_a (
+    id INTEGER PRIMARY KEY AUTOINCREMENT,
+    name TEXT NOT NULL,
+    b INTEGER
+);
+
+CREATE TABLE test6_b (
+    id INTEGER PRIMARY KEY AUTOINCREMENT,
+    name TEXT NOT NULL
 );
 
 COMMIT;
